@@ -7,10 +7,14 @@ import (
 
 const (
 	RedHatImageRegistry = "registry.redhat.io"
+	Apicurito16Image    = "fuse-apicurito"
+
+	Apicurito16ImageTag = "1.8"
+	Apicurito16ImageURL = RedHatImageRegistry + "/fuse7/" + Apicurito16Image + ":" + Apicurito16ImageTag
+
+	Generator16Image    = "fuse-apicurito-generator"
+	Generator16ImageURL = RedHatImageRegistry + "/fuse7/" + Generator16Image + ":" + Apicurito16ImageTag
 
-	Apicurito16Image     = "fuse-apicurito"
-	Apicurito16ImageTag  = "1.7"
-	Apicurito16ImageURL  = RedHatImageRegistry + "/fuse7/" + Apicurito16Image + ":" + Apicurito16ImageTag
 	Apicurito16Component = "fuse-apicurito-openshift-container"
 )
 
